@@ -1,4 +1,14 @@
-import importlib
+"""Unicode to ASCII transliteration"""
+
+from sys import intern
+from zlib import decompress, MAX_WBITS
+
+try:
+    from importlib.resources import read_binary
+except ImportError:
+    from pkgutil import get_data as read_binary
+
+__version__ = '0.1.7'
 
 _blocks = {}
 
@@ -16,8 +26,10 @@ def anyascii(string):
             block = _blocks[blocknum]
         except KeyError:
             try:
-                block = importlib.import_module('anyascii._data._%03x' % blocknum).b
-            except ImportError:
+                b = read_binary('anyascii._data', '%03x' % blocknum)
+                s = decompress(b, -MAX_WBITS).decode('ascii')
+                block = tuple(map(intern, s.split('\t')))
+            except FileNotFoundError:
                 block = ()
             _blocks[blocknum] = block
         if len(block) > lo:
